==> trilinos-15.0.0-3-x86_64.pkg.tar.zst: usr/lib/cmake/STKTools/STKToolsTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RELEASE".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "STKTools::stk_transfer_utils_lib" for configuration "RELEASE"
set_property(TARGET STKTools::stk_transfer_utils_lib APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(STKTools::stk_transfer_utils_lib PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libstk_transfer_utils_lib.so.15.0"
  IMPORTED_SONAME_RELEASE "libstk_transfer_utils_lib.so.15"
  )

list(APPEND _cmake_import_check_targets STKTools::stk_transfer_utils_lib )
list(APPEND _cmake_import_check_files_for_STKTools::stk_transfer_utils_lib "${_IMPORT_PREFIX}/lib/libstk_transfer_utils_lib.so.15.0" )

# Import target "STKTools::stk_tools_lib" for configuration "RELEASE"
set_property(TARGET STKTools::stk_tools_lib APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(STKTools::stk_tools_lib PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libstk_tools_lib.so.15.0"
  IMPORTED_SONAME_RELEASE "libstk_tools_lib.so.15"
  )

list(APPEND _cmake_import_check_targets STKTools::stk_tools_lib )
list(APPEND _cmake_import_check_files_for_STKTools::stk_tools_lib "${_IMPORT_PREFIX}/lib/libstk_tools_lib.so.15.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> trilinos-15.1.1-1-x86_64.pkg.tar.zst: usr/lib/cmake/STKTools/STKToolsTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RELEASE".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "STKTools::stk_transfer_utils_lib" for configuration "RELEASE"
set_property(TARGET STKTools::stk_transfer_utils_lib APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(STKTools::stk_transfer_utils_lib PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libstk_transfer_utils_lib.so.15.1.1"
  IMPORTED_SONAME_RELEASE "libstk_transfer_utils_lib.so.15"
  )

list(APPEND _cmake_import_check_targets STKTools::stk_transfer_utils_lib )
list(APPEND _cmake_import_check_files_for_STKTools::stk_transfer_utils_lib "${_IMPORT_PREFIX}/lib/libstk_transfer_utils_lib.so.15.1.1" )

# Import target "STKTools::stk_tools_lib" for configuration "RELEASE"
set_property(TARGET STKTools::stk_tools_lib APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(STKTools::stk_tools_lib PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libstk_tools_lib.so.15.1.1"
  IMPORTED_SONAME_RELEASE "libstk_tools_lib.so.15"
  )

list(APPEND _cmake_import_check_targets STKTools::stk_tools_lib )
list(APPEND _cmake_import_check_files_for_STKTools::stk_tools_lib "${_IMPORT_PREFIX}/lib/libstk_tools_lib.so.15.1.1" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
